@@ -128,7 +128,7 @@ DEFAULT_CONFIG = '''version:
 changelog:
   ai:
     enabled: true
-    model: "gpt-4"
+    model: "gpt-4o-mini"
     temperature: 0.7
     max_tokens: 1000
     response_format:
